Le justiciable devant les tribunaux criminels à Paris | Criminocorpus
Author: Danis Habib, Sylvie Nicolas
Description: Vers un nouvel ordre judiciaire Sous l’Ancien Régime, toute justice émane du roi. Le système judiciaire repose sur une organisation hiérarchique complexe où règne une grande confusion des pouvoirs due à une juxtaposition des juridictions. Au XVIIIe siècle, un mouvement réformateur de la justice touche les monarchies éclairées. En France, les critiques se multiplient, relayées par les philosophes. Louis XVI lui-même prend quelques mesures. Mais une réforme d’ampleur, que les cahiers de doléances réclament, s’impose. Portés par le courant des Lumières, les Constituants suppriment tout le système existant et s’attèlent aussitôt à la tâche colossale d ...
Date: 2010-01-22

# Le justiciable devant les tribunaux criminels à Paris (1790-1792)

Date de publication : 22 janvier 2010
Tweeter

### Danis Habib, Sylvie Nicolas

#### Pour citer cette page

Danis Habib, Sylvie Nicolas. Le justiciable devant les tribunaux criminels à Paris (1790-1792), Criminocorpus [En ligne] publiée le 22 janvier 2010, consultée le 30 juin 2013.
URL : https://criminocorpus.org/musee/282/

Vers un nouvel ordre judiciaire

Sous l’Ancien Régime, toute justice émane du roi. Le système judiciaire repose sur une organisation hiérarchique complexe où règne une grande confusion des pouvoirs due à une juxtaposition des juridictions. Au XVIIIe siècle, un mouvement réformateur de la justice touche les monarchies éclairées. En France, les critiques se multiplient, relayées par les philosophes. Louis XVI lui-même prend quelques mesures. Mais une réforme d’ampleur, que les cahiers de doléances réclament, s’impose. Portés par le courant des Lumières, les Constituants suppriment tout le système existant et s’attèlent aussitôt à la tâche colossale d’une réorganisation judiciaire dont les grandes lignes perdurent encore.

Cependant, l’enthousiasme révolutionnaire qui anime les hommes au pouvoir ne leur enlève ni la conscience des réalités ni le souci de l’ordre public : nombreux sont les procès inachevés, inévitables les affaires à venir. D’où la mise en place d’un système de transition qui permet une jonction entre l’ancien et le nouvel ordre judiciaire.

Ainsi la Révolution poursuit-elle le crime : commissaires, juges, greffiers, enquêtent, interrogent, collectent les pièces à conviction. Une partie de leurs archives nous sont parvenues intactes, quelquefois dans leurs sacs de jute d’origine : dossiers d’instruction, de procédure ou de jugement, pièces à conviction telles que portefeuilles, faux tampons, lettres anonymes, fioles, limes, tasses - sources infiniment précieuses pour l’histoire de la vie quotidienne à Paris sous la Révolution.

### 1. Les tribunaux de la Révolution

Cliquez pour agrandir
En matière de justice, les Constituants opèrent une révolution complète. Toutes les juridictions existantes sont supprimées. La souveraineté émane désormais de la Nation, d’où le principe d’élection des juges et la création des jurys.

En 1790, une nouvelle organisation se met en place qui distingue deux ordres de justice :

* une justice de droit commun

- justice civile : juges de paix, tribunaux de district
- justice pénale : police municipale, tribunal de police correctionnelle, tribunal criminel départemental
- au sommet, le Tribunal de cassation * une justice politique : Haute Cour nationale.

Mais à Paris, en attendant la mise en route de ce système et pour résoudre le sort de l’arriéré d’Ancien Régime, deux solutions de transition sont adoptées en matière pénale :

* des juridictions pénales provisoires sont créées :

- le Tribunal des dix
- six tribunaux criminels provisoires

* une compétence criminelle est attribuée provisoirement à certains tribunaux civils :

- aux six tribunaux d’arrondissement
- au Tribunal criminel extraordinaire du 17 août 1792

La disparition en 1871 des archives des tribunaux d’arrondissement dans les incendies de la Commune limite l’analyse des affaires criminelles parisiennes aux seuls procès portés devant les juridictions pénales provisoires, qui ont échappé à la destruction parce que versés dès 1847 aux Archives nationales. L’étude n’est donc possible que de décembre 1790 à décembre 1792.

**Le Tribunal des dix (1790-1791) En attendant l’installation des tribunaux d’arrondissement de Paris en janvier 1791, et devant le nombre de procès criminels restés pendants au parlement de Paris, fermé le 15 octobre 1790, la Constituante crée, par le décret des 1er-5 décembre 1790, un tribunal provisoire d’appel pour juger les affaires criminelles venues du Châtelet et des autres sièges royaux ou seigneuriaux du ressort du parlement de Paris.

Communément appelé Tribunal des dix car composé des dix premiers juges, non-députés à l’Assemblée, élus au scrutin pour les tribunaux de district, il s’installe le 9 décembre au palais de justice dans la salle Saint-Louis et la Petite Tournelle ; il siège du 10 décembre 1790 au 24 janvier 1791, veille de la mise en place des nouveaux tribunaux d’arrondissement.

**Les Tribunaux d’arrondissement (1790-192) Créés par le décret des 16-24 août 1790, les six tribunaux de district (dits à Paris : « d’arrondissement ») auxquels sont rattachés les cantons de Saint-Denis et Bourg-la-Reine, s’installent en janvier 1791.

Ce sont des juridictions civiles, provisoirement compétentes au criminel en attendant de structurer la procédure criminelle. Cette compétence leur est ôtée lors de la parenthèse des tribunaux criminels provisoires. Ils cessent de fonctionner en l’an III et les procès pendants sont acheminés au tribunal civil de la Seine (commencés sans jury, ils doivent être jugés sans jury).

L’incendie de leurs archives en 1871 rend impossible l’étude de leur activité en matière criminelle. Faute de documents, on ne peut pas déterminer la proportion des anciens et des nouveaux procès criminels traités.

** Les Tribunaux criminels provisoires (1791-1792) Pour soulager les tribunaux d’arrondissement et pour juger l’arriéré existant au 25 janvier 1791, six tribunaux criminels provisoires, composés de sept juges, sont créés par le décret des 13-14 mars 1791 : ils reprennent les affaires restées pendantes devant les juridictions d’Ancien Régime supprimées, Châtelet ou Parlement.

Leur compétence criminelle devient entière lorsque leur sont dévolus les procès criminels des tribunaux d’arrondissement à l’exception de ceux relatifs à la fabrication de faux assignats (décret des 17-29 septembre 1791). Ces tribunaux n’appliquent pas encore la nouvelle procédure avec les deux jurys.

Ils sont définitivement supprimés par le décret des 24-25 décembre 1792 et les procès restant à juger sont renvoyés devant les tribunaux d’arrondissement correspondants.

** Le tribunal du 17 août 1792. Première juridiction d’exception, jugeant en dernier ressort, le Tribunal criminel extraordinaire, créé par le décret du 17 août 1792 pour les crimes liés aux événements qui se sont déroulés à Paris dans la journée du 10 août, voit sa compétence étendue par le décret du 11 septembre 1792 aux crimes commis dans le département de Paris.

Le parti modéré lui reproche vite ses origines jacobines et le ministre de la Justice dénonce comme un excès de pouvoir une procédure, en matière de droit commun, sans appel ni cassation. Le décret des 15-17 novembre 1792 rétablit alors le recours en cassation. Puis le décret du 29 novembre 1792 supprime la juridiction à compter du 1er décembre et renvoie les affaires aux tribunaux ordinaires.

Cet épisode a donné l’occasion à un certain Fouquier-Tinville de faire ses premières armes comme directeur d’un des jurys d’accusation…

### 2. Faites entrer les accusés !

La délinquance à laquelle se consacre la justice criminelle parisienne provisoire présente une parfaite continuité avec celle de l’Ancien Régime : la sociologie des accusés est réellement la même que dans les années précédentes.

Avec la suppression des juridictions et les départs en émigration, il y a certes un peu plus de gratte-papiers, de saute-ruisseaux ou de domestiques ayant perdu leur place. La délinquance profite sans doute des carences policières et des désordres. De fait, toutes les infractions ne sont pas portées devant les tribunaux criminels. Cependant, auteurs, actes et victimes restent les mêmes.

Cette délinquance concerne indifféremment hommes et femmes. Si les premiers sont plus nombreux et audacieux, les secondes servent souvent d’auxiliaires : complices ou receleuses. Les prévenus appartiennent à ce que l’on appelle le petit peuple : métiers urbains, classes modestes. Peu sont des marginaux habitués de la rue qui commettent le plus souvent des infractions mineures, sans circonstances aggravantes, relevant de la police municipale ou de la justice correctionnelle.

Les délinquants opèrent seuls, sans préméditation, quand l’occasion se présente, ou en petits groupes. Lorsque l’objet du larcin est de valeur, le voleur implique d’autres complices : receleurs, revendeurs. Les faussaires, eux, mettent en place tout un réseau y compris dans les prisons ! Seul le vol du Garde-Meuble rassemble une quarantaine de comparses tout en restant d’ailleurs une opération très empirique. Un boulanger, un fripier, un journalier, un commis… Tel est l’échantillon représentatif des prévenus qui comparaissent devant les tribunaux criminels provisoires, issus de cette masse qui fait les rassemblements des journées révolutionnaires.

Une grande majorité appartient aux petits métiers parisiens, organisés en corporations jusqu’en 1791 : boucher, limonadier, tailleur, lingère, coiffeur, graveur, imprimeur, maçon, serrurier, etc. Si beaucoup sont des garçons, probablement sans place, nombreux sont aussi les compagnons. Les autres accusés sont des gagne–deniers, souvent entre deux emplois précaires, des domestiques, quelques commis en exercice et des hommes enrôlés ou travaillant au camp militaire installé « sous Paris », des membres de la minorité juive, quelques marginaux : mendiants ou filles publiques.

Les fonds d’archives des juridictions révolutionnaires comportent parfois, avec les dossiers de procédure, ceux des objets saisis dont la conservation a été possible, à l’exclusion des denrées périssables (aliments), d’utilité quotidienne (vêtements), de valeur (bijoux) ou de grande taille (haches, bahuts).

Les pièces à conviction présentées dans l’exposition sont parvenues aux Archives nationales avec les dossiers du Tribunal des dix et des tribunaux criminels provisoires mais sans identification particulière. La raison de leur saisie n’est pas évidente : objets volés ou objets pris sur les inculpés, voire à leur domicile, pour étayer l’accusation ?

Anonymes et non identifiables mais toujours poignants, ces articles donnent aux affaires une dimension concrète et apportent un éclairage sur certains aspects de la vie quotidienne.

### 3. Crimes et délits

L’Ancien Régime répartit les infractions, suivant la procédure, en grand et petit criminel selon que la faute mérite une peine afflictive, voire infamante, ou seulement une amende. Mais aucun corpus pénal ne consacre le principe de la légalité des incriminations et des peines.

Le Code pénal de 1791 est le premier du genre en France. Il ne s’intéresse qu’aux infractions criminelles, qu’il classifie, selon la vision politique des Constituants, en ordre décroissant d’importance : contre la chose publique dans le but de protéger le régime nouveau et de défendre les citoyens contre les abus de pouvoir, contre les particuliers, d’abord dans leurs personnes (principes de liberté et d’égalité) puis dans leurs biens (défense de la propriété). Les crimes religieux (blasphème, suicide, sacrilège, adultère, etc.) sont abolis.

Seules les infractions les plus graves sont du ressort de la justice criminelle. Les dossiers des tribunaux criminels provisoires présentent cependant une multitude d’affaires que l’on se serait attendu à voir relever de la justice correctionnelle, tel le vol d’un panier de poires. Point de laxisme donc, ni chez les législateurs, ni chez les juges, souvent petits bourgeois soucieux certes de liberté individuelle mais pas au prix du maintien de l’ordre, de la sécurité des citoyens ou de la sûreté des propriétés : voleurs, escrocs, auteurs de sévices n’ont qu’à bien se tenir ! Et pourtant, on doit aussi faire la part, sans pouvoir l’apprécier précisément, des infractions qui restent sans suite faute de plainte ou de preuves.

La section 2 du titre II du Code pénal énumère les crimes et attentats contre les propriétés : vol sous toutes ses formes, destruction de digues, empoisonnement de bétail, récidive de vente à faux poids ou mesure, pillage, banqueroute frauduleuse, extorsion de signature, faux, destruction de titres ; incendie ou pose de mine ; détournement d’effets en garde ; faux témoignage.

Comme sous l’Ancien Régime, le vol constitue la majorité des affaires criminelles : aliments, portefeuilles, argenterie, matériaux, linge, bétail, etc. - tout objet souvent en relation avec le métier exercé. Ses circonstances aggravantes sont l’effraction, l’emploi de fausses clefs, l’escalade ou la complicité interne. L’extorsion d’aumône n’est pas rare...

Les peines sont diverses : fers ou détention, mais aussi dégradation civique, gêne ou mort, majorées si le délit est commis la nuit, à plusieurs, avec armes.

Toute une section du Code pénal se rapporte aux crimes et attentats contre les personnes. Dix-huit articles portent sur l’homicide : involontaire, légal ou légitime, il ne donne lieu à aucune condamnation ; volontaire, il peut être avec ou sans préméditation, et prendre la forme d’empoisonnement, de parricide ou d’avortement.

Seules les blessures importantes donnent lieu à une poursuite au pénal. Préméditation et guet-apens sont des circonstances aggravantes. Mutilation, castration et viol sont nommément désignés ainsi que l’enlèvement pour prostitution.

Les deux derniers articles sont consacrés à la destruction d’état civil ou à la bigamie légale (second mariage sans dissolution du premier). Les châtiments, gradués en fonction de la sévérité des lésions, sont la mort, les fers, la gêne ou la détention.

Le titre I de la 2e partie du Code pénal répartit les attentats contre la chose publique en crimes contre la sûreté de l’État, la Constitution, la loi et les pouvoirs constitués, crimes des commis de l’État dans l’exercice de leurs fonctions, crimes contre la propriété publique.

Dans cette dernière rubrique entrent les contrefaçons de monnaie, sceau, timbre national ou poinçon, le vol de deniers publics ou la destruction de propriétés de l’État qui sont des atteintes aux fonctions régaliennes mais n’ont pas l’envergure d’un crime de lèse-Nation que le Code pénal n’aborde pas.

Plusieurs affaires de faux bons de caisse ou de congés militaires sont jugées par les tribunaux criminels provisoires, tandis que le rocambolesque épisode du Garde-Meuble national relève du Tribunal du 17 août.

La mort est la peine la plus fréquente.

### 4. L’affaire est dans le sac !

Avant la Révolution, la procédure est inquisitoire, secrète, entièrement écrite, fondée sur les preuves légales, afin de protéger les prévenus de l’intime conviction du juge, avec un ministère public fort où les intérêts de l’État priment sur ceux de la victime.

Dès l’automne 1789, une procédure transitoire se met en place basée sur l’ordonnance de 1670 aménagée par le décret des 8-9 octobre 1789 ; toujours inquisitoire, avec un ministère public fort et fondée sur des preuves légales qui sont désormais les témoignages et expertises, elle se déroule en deux phases :

1 - une phase de publicité atténuée en présence de deux notables-adjoints :

- information
- interrogatoire

2 - une phase de publicité dorénavant intégrale en présence du conseil :

- instruction (confirmation des dépositions, confrontation témoins/accusés, conclusion du procureur général)
- audience (rapport du juge, dernier interrogatoire de l’accusé, preuve de faits justificatifs par l’accusé, sentence)
- voies de recours.

La nouvelle procédure, accusatoire, mise en place par le décret des 29 septembre-21 octobre 1791 se déroulera en trois temps :

- instruction préparatoire menée par un officier de police judiciaire, saisi ou non d’une plainte ou d’une dénonciation, et mandat d’arrêt
- comparution devant un jury d’accusation qui décide s’il y a lieu ou non à accuser
- procès : un jury de jugement, doit par vote, sur son intime conviction (ce qui met fin au système des preuves légales), s’exprimer sur la seule culpabilité. Enfin, les juges prononcent en « automates » la peine prévue par la loi.

Le législateur de 1791 distingue les accusés, détenus dans les maisons d’arrêt et de justice, des condamnés, enfermés dans des prisons établies pour les peines. Mais faute de bâtiments, les uns et autres se retrouvent dans les mêmes lieux (Conciergerie, Grand Châtelet, la Force, etc.).

Selon un récit contemporain, il y règne « une puanteur insupportable, un air infect, des guichetiers ivres [...] chargés d’énormes clefs et suivis de chiens faits comme eux pour répandre l’épouvante […]. Les pailles dont se compose la litière des prisonniers, corrompues par le défaut d’air et par la puanteur des seaux où les prisonniers font leurs besoins, exhalent une infection telle que, dans le greffe même, on est empoisonné lorsqu’on ouvre les portes […] il en est ainsi des cachots où des hommes, reconnus ensuite innocents, ont passé des mois entiers ».

Les règles de la procédure criminelle, trait d’union entre l’infraction et la peine, sont déterminées par la préoccupation de poursuivre les infractions et de garantir les droits de la personne. La Constituante décide des innovations considérables dès 1789 : légalité des peines, assistance de notables-adjoints, conseil et publicité des débats. Le décret des 29 septembre-21 octobre 1791 et le Code pénal entraînent un bouleversement complet en mettant en œuvre la procédure avec jurys et en faisant appel à l’intime conviction. Le prévenu et les témoins sont interrogés à plusieurs étapes, confrontés entre eux ; appel plus systématique est fait à des experts (expert en écriture, serruriers, médecins, etc.). Le rôle des juges est limité : plus d’arbitraire, ils n’ont qu’à appliquer les peines prévues par la loi !

Le Code pénal de 1791, est l’aboutissement d’un siècle de critiques des esprits éclairés contre les peines de l’Ancien Régime.

La rupture est totale. Les peines sont désormais égales pour tous, strictement personnelles (la confiscation des biens est abolie), temporaires et fixes en fonction des délits. Les châtiments physiques sont supprimés. La mort est maintenue, contre l’avis des abolitionnistes, mais avec application à tous du privilège de décollation.

De nouvelles peines apparaissent (prison, fers, dégradation civique) dans un esprit d’utilité sociale et de rédemption laïque. Fondement du système, l’emprisonnement, jusque-là préventif, prive le citoyen de son bien le plus précieux, la liberté mais jamais à perpétuité, dans l’espoir d’un amendement. L’humiliation demeure avec l’exposition. La publicité de certains châtiments maintient un aspect théâtral dissuasif.
Force reste à la loi !

Les journées d’émeute de cette première période révolutionnaire, qui correspond à la mise en place d’une monarchie constitutionnelle et à son échec, cachent sans doute une réalité bien mieux policée qu’on ne le pense.

Les Constituants, soucieux de l’ordre public, ont évité un vide juridictionnel et accompli en peu de temps une œuvre colossale. Les magistrats s’investissent totalement, sans aucune permissivité, dans un réel souci de police et de justice : chaque délit même minime mérite son châtiment et chaque châtiment doit servir de dissuasion. Parfois obscurs hommes de loi, ils espèrent assurer leur subsistance mais sont aussi conscients de participer à une construction nouvelle. Cependant malgré un travail intensif et ininterrompu, ils ne viennent pas à bout de la multitude des affaires.

Mais l’idée de justice est sauve...

La Révolution à la poursuite du crime ! (exposition) ↑ Retourner en haut ↑ Compléments
Chargement en cours…